<?php
/**
 * Chrisporate Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function chrisporate_pro_customize_register( $wp_customize ) {
	$options = chrisporate_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'chrisporate_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'chrisporate-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'chrisporate_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'chrisporate-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'chrisporate_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'chrisporate-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'chrisporate-pro' ),
			'show-all'     => esc_html__( 'Show All', 'chrisporate-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'chrisporate-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'chrisporate-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'chrisporate-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'chrisporate-pro' ),
			)
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'chrisporate_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[colorscheme]', array(
		'type'    	=> 'radio',
		'label'    	=> esc_html__( 'Color Scheme', 'chrisporate-pro' ),
		'choices'  	=> array(
			'xmas'   	=> esc_html__( 'X-mas', 'chrisporate-pro' ),
			'default'  	=> esc_html__( 'Corporate', 'chrisporate-pro' ),
			'blue'   	=> esc_html__( 'Blue', 'chrisporate-pro' ),
			'green'   	=> esc_html__( 'Green', 'chrisporate-pro' ),
			'red'   	=> esc_html__( 'Red', 'chrisporate-pro' ),
			'yellow'   	=> esc_html__( 'Yellow', 'chrisporate-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'chrisporate_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'chrisporate_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'chrisporate_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','chrisporate-pro' ),
	    'description'=> esc_html__( 'Chrisporate Pro Theme Options.', 'chrisporate-pro' ),
	    'priority'   => 150,
	) );

	// snow
	require get_template_directory() . '/inc/customizer/theme-options/snow.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// side menu
	require get_template_directory() . '/inc/customizer/theme-options/side-menu.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load sortable option
	require get_template_directory() . '/inc/customizer/theme-options/sortable.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'chrisporate_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Home Page','chrisporate-pro' ),
	    'description'=> esc_html__( 'Home Page Theme Options.', 'chrisporate-pro' ),
	    'priority'   => 140,
	) );

	// load banner option
	require get_template_directory() . '/inc/customizer/sections/banner.php';

	// load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// load services option
	require get_template_directory() . '/inc/customizer/sections/services.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	// load portfolio option
	require get_template_directory() . '/inc/customizer/sections/portfolio.php';

	// load author option
	require get_template_directory() . '/inc/customizer/sections/author.php';

	// load latest blog option
	require get_template_directory() . '/inc/customizer/sections/latest-blog.php';

	// load testimonial option
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// load client option
	require get_template_directory() . '/inc/customizer/sections/client.php';

	// load contact option
	require get_template_directory() . '/inc/customizer/sections/contact.php';

	// load map option
	require get_template_directory() . '/inc/customizer/sections/map.php';

	// load subscription option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';


}
add_action( 'customize_register', 'chrisporate_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function chrisporate_pro_customize_preview_js() {
	wp_enqueue_script( 'chrisporate-pro-customizer-preview', get_template_directory_uri() . '/assets/js/customizer' . chrisporate_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'chrisporate_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function chrisporate_pro_customize_control_js() {

	wp_enqueue_style( 'chrisporate-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . chrisporate_pro_min() . '.css' );

	wp_enqueue_script( 'chrisporate-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . chrisporate_pro_min() . '.js', array( 'jquery', 'customize-controls', 'iris', 'underscore', 'wp-util' ), '', true );
	$chrisporate_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'chrisporate-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'chrisporate-pro-customize-controls', 'chrisporate_pro_reset_data', $chrisporate_pro_reset_data );

}
add_action( 'customize_controls_enqueue_scripts', 'chrisporate_pro_customize_control_js' );

if ( !function_exists( 'chrisporate_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Chrisporate Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function chrisporate_pro_reset_options() {
		$options = chrisporate_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'chrisporate_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_video' );
			remove_theme_mod( 'external_header_video' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'chrisporate_pro_reset_options' );
