<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 * @return array An array of default values
 */

function chrisporate_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$chrisporate_pro_default_options = array(
		
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#222328',
		'colorscheme'					=> 'xmas',
		'snow_fall'						=> true,

		// side icon menu
		'side_menu'						=> true,

		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'fa-circle-o-notch',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',

		// header menu
		'menu_sticky'					=> false,
		'menu_style'					=> 'modern-menu',

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'		        => esc_html__( 'Read More', 'chrisporate-pro' ),
		
		// breadcrumb options
		'breadcrumb_enable'         	=> true,
		'breadcrumb_separator'         	=> '/',

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// Sortable
		'sortable'						=> 'About,Services,Counter,Portfolio,Author,Latest Blog,Testimonial,Team,Client',

		// footer options
		'footer_image_enable'			=> true,
		'footer_social_enable'			=> false,
		'footer_image'					=> get_template_directory_uri() . '/assets/uploads/footer-logo.png',
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s.', '1: Year, 2: Site Title with home URL', 'chrisporate-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'chrisporate-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'chrisporate-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'chrisporate-pro' ),
		'show_date' 					=> true,
		'show_category' 				=> true,
		'show_author'					=> true,
		'show_readmore'					=> true,
		'no_featured_image'				=> false,

		// single post theme options
		'single_post_show_date' 		=> true,
		'single_post_show_author'		=> true,
		'single_post_show_category'		=> true,
		'single_post_show_tags'			=> true,
		'single_post_show_comment'		=> true,
		'single_post_show_pagination'	=> true,

		/* Front Page */

		// Banner
		'banner_section_title'			=> esc_html__( 'Simple Yet Beautiful', 'chrisporate-pro' ),
		'banner_section_sub_title'		=> esc_html__( 'Interfaces', 'chrisporate-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_menu_icon'				=> 'fa-user',
		'about_content_type'			=> 'demo',
		'about_skills_enable'			=> false,
		'about_social_enable'			=> false,
		'about_title'					=> esc_html__( 'About Us', 'chrisporate-pro' ),
		'about_description'				=> esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' ),
		'about_graph'					=> '[TP_PIEBUILDER_HORIZONTAL_BAR title="" values="90, 85, 95" labels="Design, Development, Production" colors="#000, #000, #000"]',

		// Services
		'service_section_enable'		=> true,
		'service_menu_icon'				=> 'fa-cog',
		'service_title_type'			=> 'demo',
		'service_title'					=> esc_html__( 'Services', 'chrisporate-pro' ),
		'service_description'			=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' ),
		'service_content_type'			=> 'demo',
		'service_count'					=> 4,

		// Counter
		'counter_section_enable'		=> true,
		'counter_menu_icon'				=> 'fa-star-o',
		'counter_content_type'			=> 'demo',
		'counter_count'					=> 4,
		'counter_background_image'		=> get_template_directory_uri() . '/assets/uploads/counter.jpg',
		'counter_section_title'			=> esc_html__( 'Design', 'chrisporate-pro' ),
		'counter_section_icon'			=> 'fa-pencil-square-o',
		'counter_section_value'			=> 526,

		// Portfolio
		'portfolio_section_enable'		=> true,
		'portfolio_menu_icon'			=> 'fa-industry',
		'portfolio_title_type'			=> 'demo',
		'portfolio_title'				=> esc_html__( 'Portfolio', 'chrisporate-pro' ),
		'portfolio_description'			=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' ),
		'portfolio_content_type'		=> 'demo',
		'portfolio_count'				=> 4,
		'portfolio_load_more'			=> 'ajax',
		'portfolio_section_layout'		=> 'col-2',
		'portfolio_btn_label'			=> esc_html__( 'Load More Portfolio', 'chrisporate-pro' ),

		// Author
		'author_section_enable'			=> true,
		'author_menu_icon'				=> 'fa-id-badge',
		'author_content_type'			=> 'demo',
		'author_count'					=> 2,
		'author_title'					=> esc_html__( 'Milena Newman', 'chrisporate-pro' ),
		'author_sub_title'				=> esc_html__( 'UI/UX Designer', 'chrisporate-pro' ),
		'author_description'			=> esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' ),
		'author_image'					=> get_template_directory_uri() . '/assets/uploads/author-slider.png',
		'author_social'					=> 'www.facebook.com',

		// Latest Blog
		'latest_blog_section_enable'	=> true,
		'latest_blog_menu_icon'			=> 'fa-newspaper-o',
		'latest_blog_section_layout'	=> 'col-3',
		'latest_blog_title_type'		=> 'demo',
		'latest_blog_title'				=> esc_html__( 'Latest Blog', 'chrisporate-pro' ),
		'latest_blog_description'		=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' ),
		'latest_blog_content_type'		=> 'demo',
		'latest_blog_count'				=> 3,
		'latest_blog_load_more'			=> 'ajax',
		'latest_blog_btn_label'			=> esc_html__( 'Load More Blog', 'chrisporate-pro' ),

		// Testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_menu_icon'			=> 'fa-commenting-o',
		'testimonial_content_type'		=> 'demo',
		'testimonial_count'				=> 2,
		'testimonial_background_image'	=> get_template_directory_uri() . '/assets/uploads/testimonial.jpg',
		'testimonial_section_title'		=> esc_html__( 'What People Say?', 'chrisporate-pro' ),
		'testimonial_title'				=> esc_html__( 'Robert Lionel', 'chrisporate-pro' ),
		'testimonial_description'		=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi.', 'chrisporate-pro' ),

		// Team
		'team_section_enable'			=> true,
		'team_menu_icon'				=> 'fa-users',
		'team_title_type'				=> 'demo',
		'team_title'					=> esc_html__( 'Our Team', 'chrisporate-pro' ),
		'team_description'				=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' ),
		'team_content_type'				=> 'demo',
		'team_title'					=> esc_html__( 'James Handerson', 'chrisporate-pro' ),
		'team_sub_title'				=> esc_html__( 'Web Developer', 'chrisporate-pro' ),
		'team_quote'					=> esc_html__( 'Hello, I am James henderson. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus ac felis risus.', 'chrisporate-pro' ),
		'team_description'				=> esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' ),
		'team_image'					=> get_template_directory_uri() . '/assets/uploads/team-01.jpg',

		// Client
		'client_section_enable'			=> true,
		'client_menu_icon'				=> 'fa-handshake-o',
		'client_content_type'			=> 'demo',
		'client_count'					=> 6,
		'client_image'					=> get_template_directory_uri() . '/assets/uploads/client-01.png',
		'client_title'					=> esc_html__( 'Client Logo', 'chrisporate-pro' ),

		// Contact
		'contact_section_enable'		=> false,
		'contact_menu_icon'				=> 'fa-phone',
		'contact_title_type'			=> 'demo',
		'contact_address'				=> esc_html__( 'Jawalakhel, Lalitpur', 'chrisporate-pro' ),
		'contact_phone'					=> esc_html__( '+00 0 0000000', 'chrisporate-pro' ),
		'contact_email'					=> esc_html__( 'abc@email.com', 'chrisporate-pro' ),
		'contact_title'					=> esc_html__( 'Find Us', 'chrisporate-pro' ),
		'contact_description'			=> esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' ),

		// Map
		'map_section_enable'			=> true,
		'map_content_type'				=> 'shortcode',
		'map_content_shortcode'				=> '[wpgmza id="1"]',

		// Subscription
		'subscription_section_enable'	=> false,
		'subscription_title'			=> esc_html__( 'Stay updated with us!', 'chrisporate-pro' ),


	);

	$output = apply_filters( 'chrisporate_pro_default_theme_options', $chrisporate_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}