<?php
/**
 * Latest Blog Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Latest Blog section
$wp_customize->add_section( 'chrisporate_pro_latest_blog_section', array(
	'title'             => esc_html__( 'Latest Blog Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Latest Blog Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Latest Blog content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_section_enable]', array(
	'default'			=> 	$options['latest_blog_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[latest_blog_section_enable]', array(
	'label'             => esc_html__( 'Latest Blog Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Latest Blog content layout control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_section_layout]', array(
	'default'          	=> $options['latest_blog_section_layout'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_section_layout]', array(
	'label'             => esc_html__( 'Layout', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_enable',
	'choices'			=> array( 
		'col-2' 	=> esc_html__( 'Two Column', 'chrisporate-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'chrisporate-pro' ),
	),
) );

// Latest Blog content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_title_type]', array(
	'default'          	=> $options['latest_blog_title_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_title_type]', array(
	'label'             => esc_html__( 'Title Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_title_page]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_page'
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_title_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_latest_blog_section',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_title_page_enable',
	'type'				=> 'dropdown-pages'
) );

// Latest Blog Section title type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_title_post]', array(
	'validate_callback' => 'chrisporate_pro_validate_post_id',
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_title_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_latest_blog_section_title_post_enable',
	'label'             => esc_html__( 'Input Post Id', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Latest Blog title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_latest_blog_section',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_title_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[latest_blog_title]', array(
		'selector'            => '#latest-blog .container .latest-content-title .entry-header h2.entry-title',
		'settings'            => 'chrisporate_pro_theme_options[latest_blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_latest_blog_title_partial',
    ) );
}

// Latest Blog description setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['latest_blog_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_description]', array(
	'label'           	=> esc_html__( 'Description', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_latest_blog_section',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_title_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[latest_blog_description]', array(
		'selector'            => '#latest-blog .container .latest-content-title p.description',
		'settings'            => 'chrisporate_pro_theme_options[latest_blog_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_latest_blog_description_partial',
    ) );
}

// Latest Blog hr setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_section_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[latest_blog_section_hr]',
	array(
		'section'         => 'chrisporate_pro_latest_blog_section',
		'active_callback' => 'chrisporate_pro_is_latest_blog_section_enable',
		'type'			  => 'hr'
) ) );


// Latest Blog content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_content_type]', array(
	'default'          	=> $options['latest_blog_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'all' 		=> esc_html__( 'All Posts', 'chrisporate-pro' ),
		'category' 	=> esc_html__( 'Category', 'chrisporate-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_count]', array(
	'default'          	=> $options['latest_blog_count'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_number_range',
	'validate_callback' => 'chrisporate_pro_validate_latest_blog_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_count]', array(
	'label'             => esc_html__( 'Number of Latest Blog', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'active_callback'   => 'chrisporate_pro_is_latest_blog_section_content_not_demo',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'chrisporate_pro_theme_options[latest_blog_content_category]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Chrisporate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'chrisporate_pro_theme_options[latest_blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'chrisporate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'chrisporate_pro_is_latest_blog_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'chrisporate_pro_theme_options[latest_blog_exclude_category]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Chrisporate_Pro_Dropdown_Category_Control( $wp_customize,'chrisporate_pro_theme_options[latest_blog_exclude_category]', array(
	'label'             => esc_html__( 'Exclude Categories', 'chrisporate-pro' ),
	'description'      	=> esc_html__( 'Note: Press SHIFT key and select multiple categories. Posts from selected categories will be excluded.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'chrisporate_pro_is_latest_blog_section_content_all_enable'
) ) );

// Latest Blog content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_load_more]', array(
	'default'          	=> $options['latest_blog_load_more'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_load_more]', array(
	'label'             => esc_html__( 'Load More Option', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_latest_blog_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_content_not_demo',
	'choices'			=> array( 
		'ajax' 		=> esc_html__( 'Ajax Load', 'chrisporate-pro' ),
		'link' 		=> esc_html__( 'Blog/Category Link', 'chrisporate-pro' ),
	),
) );

// Latest Blog loadmore btn label setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[latest_blog_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_blog_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[latest_blog_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_latest_blog_section',
	'active_callback' 	=> 'chrisporate_pro_is_latest_blog_section_content_not_demo',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[latest_blog_btn_label]', array(
		'selector'            => '#latest-blog #Lloadmore',
		'settings'            => 'chrisporate_pro_theme_options[latest_blog_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_latest_blog_btn_label_partial',
    ) );
}
