<?php
/**
 * Portfolio section
 *
 * This is the template for the content of portfolio section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_portfolio_section' ) ) :
    /**
    * Add portfolio section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_portfolio_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if portfolio is enabled on frontpage
        $portfolio_enable = apply_filters( 'chrisporate_pro_section_status', true, 'portfolio_section_enable' );

        if ( true !== $portfolio_enable ) {
            return false;
        }
        // Get portfolio section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_portfolio_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render portfolio section now.
        chrisporate_pro_render_portfolio_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_portfolio_section_details' ) ) :
    /**
    * portfolio section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input portfolio section details.
    */
    function chrisporate_pro_get_portfolio_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $portfolio_title_type     = $options['portfolio_title_type'];
        $portfolio_content_type   = $options['portfolio_content_type'];
        $portfolio_count          = ! empty( $options['portfolio_count'] ) ? $options['portfolio_count'] : 4;
        $content = array();
        $content['heading'] = array();
        $content['detail'] = array();
        switch ( $portfolio_title_type ) {
            case 'demo':
                $demo['heading']['title']      = esc_html__( 'Portfolio', 'chrisporate-pro' );
                $demo['heading']['excerpt']    = esc_html__( 'MCras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' );

                // Push to the main array.
                array_push( $content['heading'], $demo['heading'] );
            break;

            case 'custom':
                $custom['heading']['title']        = ! empty( $options['portfolio_title'] ) ? $options['portfolio_title'] : '';
                $custom['heading']['excerpt']      = ! empty( $options['portfolio_description'] ) ? $options['portfolio_description'] : '';

                // Push to the main array.
                array_push( $content['heading'], $custom['heading'] );
            break;

            case 'page':
                $page_id = ! empty( $options['portfolio_title_page'] ) ? $options['portfolio_title_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['portfolio_title_post'] ) ? $options['portfolio_title_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'post' === $portfolio_title_type || 'page' === $portfolio_title_type ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['heading']['title']     = get_the_title();
                    $page_post['heading']['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content['heading'], $page_post['heading'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }

        switch ( $portfolio_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( 'Perfect Cycle', 'chrisporate-pro' ),
                    2 => esc_html__( 'Perfect Photo frame', 'chrisporate-pro' ),
                    3 => esc_html__( 'Greenary is life', 'chrisporate-pro' ),
                    4 => esc_html__( 'Black Beauty', 'chrisporate-pro' ),
                    );
                for ( $i = 1; $i <= 4; $i++ ) {
                    $demo['detail']['image']        = get_template_directory_uri() . '/assets/uploads/gallery-0' . $i . '.jpg';
                    $demo['detail']['title']        = $title[$i];
                    $demo['detail']['url']          = '#';
                    $demo['detail']['excerpt']      = esc_html__( 'Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio porta sapien...', 'chrisporate-pro' );
                   
                    // Push to the main array.
                    array_push( $content['detail'], $demo['detail'] );
                }

            break;

            case 'category':
                $cat_id = ! empty( $options['portfolio_content_category'] ) ? $options['portfolio_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => $portfolio_count,
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    if ( ! empty( $options['portfolio_content_page_' . $i] ) )
                        $page_ids[] = $options['portfolio_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $portfolio_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = ! empty( $options['portfolio_content_post'] ) ? $options['portfolio_content_post'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

        if ( in_array( $portfolio_content_type, array( 'page', 'post', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['detail']['image']       = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-550x382.jpg';
                    $page_post['detail']['title']       = get_the_title();
                    $page_post['detail']['url']         = get_the_permalink();
                    $page_post['detail']['excerpt']     = chrisporate_pro_trim_content( 15 );

                    // Push to the main array.
                    array_push( $content['detail'], $page_post['detail'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// portfolio section content details.
add_filter( 'chrisporate_pro_filter_portfolio_section_details', 'chrisporate_pro_get_portfolio_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_portfolio_section' ) ) :
  /**
   * Start portfolio section
   *
   * @return string portfolio content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_portfolio_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();
        $portfolio_content_type   = $options['portfolio_content_type'];
        $column = ! empty( $options['portfolio_section_layout'] ) ? $options['portfolio_section_layout'] : 'col-2';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="portfolio" class="page-section relative">
            <div class="container">
                <?php foreach ( $content_details['heading'] as $content ) : ?>
                    <div class="portfolio-content-title clear">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header section-title">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header><!-- .entry-header -->
                        <?php endif; 

                        if ( ! empty( $content['excerpt'] ) ) : ?>
                            <p class="description"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .portfolio-contennt -->
                <?php endforeach; ?>

                <div class="entry-content <?php echo esc_attr( $column ); ?>">
                    <div class="row">
                        <div class="portfolio-item">
                            <?php foreach ( $content_details['detail'] as $content ) : ?>
                                <div class="hentry">
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <figure>
                                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                            </a>
                                        </figure>
                                    <?php endif; ?>
                                    <div class="portfolio-title">
                                        <h4><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
                                        <div class="entry-summary">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div>
                                    </div><!-- .portfolio-title -->
                                </div><!-- .hentry -->
                            <?php endforeach; ?>
                        </div><!-- portfolio-item -->
                    </div><!-- .row -->
                </div><!-- .entry-content / col-2 -->

                <?php if ( 'category' == $portfolio_content_type ) : 
                    $cat_link = ! empty( $options['portfolio_content_category'] ) ? get_category_link( $options['portfolio_content_category'] ) : '';
                    $btn_label = ! empty( $options['portfolio_btn_label'] ) ? $options['portfolio_btn_label'] : esc_html__( 'Load More Portfolio', 'chrisporate-pro' );
                    ?>
                    <div class="align-center">
                        <?php $icon = ! empty( $options['loader_icon'] ) ? $options['loader_icon'] : 'fa-circle-o-notch'; ?>
                        <div id="portfolio-loader" class="home-ajax-loader hide"><i class="fa <?php echo esc_attr( $icon ); ?> fa-2x fa-spin"></i></div>
                        
                        <a <?php echo ( 'ajax' == $options['portfolio_load_more'] ) ? 'id="Ploadmore"' : ''; ?> href="<?php echo ( 'link' == $options['portfolio_load_more'] ) ? esc_url( $cat_link ) : '#'; ?>" class="load-more"><?php echo esc_html( $btn_label ); ?>
                            <i class="fa fa-angle-down"></i>
                        </a>
                    </div><!-- .align-center -->
                <?php endif; ?>
            </div><!-- .container -->
        </div><!-- #portfolio -->
    <?php 
    }
endif;